<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Microsoft.UI.Xaml.Resources

Windows Runtime (WinRT) APIs for for the `Microsoft.UI.Xaml.Resources` namespace.

This package provides the `winrt.microsoft.ui.xaml.resources` module.
